summaryrefslogtreecommitdiff
path: root/passlib/handlers/sun_md5_crypt.py
diff options
context:
space:
mode:
Diffstat (limited to 'passlib/handlers/sun_md5_crypt.py')
-rw-r--r--passlib/handlers/sun_md5_crypt.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/passlib/handlers/sun_md5_crypt.py b/passlib/handlers/sun_md5_crypt.py
index a99289c..41d3331 100644
--- a/passlib/handlers/sun_md5_crypt.py
+++ b/passlib/handlers/sun_md5_crypt.py
@@ -193,7 +193,7 @@ class sun_md5_crypt(uh.HasRounds, uh.HasSalt, uh.GenericHandler):
:type rounds: int
:param rounds:
Optional number of rounds to use.
Defaults to 5000, must be between 0 and 4294963199, inclusive.
:type bare_salt: bool
:param bare_salt:
@@ -231,7 +231,7 @@ class sun_md5_crypt(uh.HasRounds, uh.HasSalt, uh.GenericHandler):
max_salt_size = None
salt_chars = uh.HASH64_CHARS
- default_rounds = 5000 # current passlib default
+ default_rounds = 5500 # current passlib default
min_rounds = 0
max_rounds = 4294963199 ##2**32-1-4096
# XXX: ^ not sure what it does if past this bound... does 32 int roll over?
@@ -193,7 +193,7 @@ class sun_md5_crypt(uh.HasRounds, uh.HasSalt, uh.GenericHandler):
:param rounds:
Optional number of rounds to use.
- Defaults to 5000, must be between 0 and 4294963199, inclusive.
+ Defaults to 5500, must be between 0 and 4294963199, inclusive.
:type bare_salt: bool
:param bare_salt: